@@ -109,11 +109,10 @@ void BarAnalyzer::analyze( const Scope &s )
     Scope &v = m_scope;
     Analyzer::interpolate( s, v );
 
-    Scope::const_iterator it( v.begin() );
-    for ( uint i = 0, x = 0, y2; i < BAND_COUNT; ++i, ++it, x+=COLUMN_WIDTH+1 )
+    for ( uint i = 0, x = 0, y2; i < v.size(); ++i, x+=COLUMN_WIDTH+1 )
     {
         //assign pre[log10]'d value
-        y2 = uint((*it) * 256); //256 will be optimised to a bitshift //no, it's a float
+        y2 = uint(v[i] * 256); //256 will be optimised to a bitshift //no, it's a float
         y2 = m_lvlMapper[ (y2 > 255) ? 255 : y2 ]; //lvlMapper is array of ints with values 0 to height()
 
         int change = y2 - barVector[i];
