@@ -12,6 +12,7 @@
 #include "amarokconfig.h"
 #include "browserbar.h"
 #include "debug.h"
+#include "enginecontroller.h"
 #include "multitabbar.h"   //m_tabBar
 
 #include <kapplication.h>  //kapp
@@ -22,14 +23,15 @@
 #include <qcursor.h>       //for resize cursor
 #include <qpainter.h>
 #include <qsignalmapper.h> //m_mapper
-#include <qstyle.h>        //amaroK::Splitter
+#include <qstyle.h>        //Amarok::Splitter
+#include <qtooltip.h>
 
 
 // we emulate a qsplitter, mostly for historic reasons, but there are still a few advantages
 // mostly we can stop the browserbar getting resized too small so that switching browser looks wrong
 
 
-namespace amaroK
+namespace Amarok
 {
     class Splitter : public QWidget {
     public:
@@ -61,22 +63,36 @@ BrowserBar* BrowserBar::s_instance = 0;
 
 BrowserBar::BrowserBar( QWidget *parent )
         : QWidget( parent, "BrowserBar" )
+        , EngineObserver( EngineController::instance() )
         , m_playlistBox( new QVBox( this ) )
-        , m_divider( new amaroK::Splitter( this ) )
-        , m_tabBar( new MultiTabBar( MultiTabBar::Vertical, this ) )
+        , m_divider( new Amarok::Splitter( this ) )
         , m_browserBox( new QVBox( this ) )
         , m_currentIndex( -1 )
         , m_lastIndex( -1 )
         , m_mapper( new QSignalMapper( this ) )
 {
+    m_tabManagementButton = new QPushButton( SmallIconSet(Amarok::icon( "configure" )), 0, this, "tab_managment_button" );
+    connect (m_tabManagementButton, SIGNAL(clicked()), SLOT(showBrowserSelectionMenu()));
+    m_tabManagementButton->setIsMenuButton ( true ); //deprecated, but since I cannot add menu directly to button it is needed.
+
+    QToolTip::add (m_tabManagementButton, i18n("Manage tabs")); 
+
+
+    m_tabBar = new MultiTabBar( MultiTabBar::Vertical, this );
+
+
+    m_tabManagementButton->setFixedWidth(m_tabBar->sizeHint().width());
+    m_tabManagementButton->setFixedHeight(m_tabBar->sizeHint().width());
+
+
     s_instance = this;
-    m_pos = m_tabBar->sizeHint().width() + 5; //5 = aesthetic spacing
+    m_pos = m_tabBar->sizeHint().width() + 5; //5 = esthetic spacing
 
     m_tabBar->setStyle( MultiTabBar::AMAROK );
     m_tabBar->setPosition( MultiTabBar::Left );
     m_tabBar->showActiveTabTexts( true );
     m_tabBar->setFixedWidth( m_pos );
-//    m_tabBar->move( 0, 3 );
+    m_tabBar->move( 0, 25 );
 
     QVBoxLayout *layout = new QVBoxLayout( m_browserBox );
     layout->addSpacing( 3 ); // aesthetics
@@ -88,11 +104,18 @@ BrowserBar::BrowserBar( QWidget *parent )
     m_playlistBox->setSpacing( 1 );
 
     connect( m_mapper, SIGNAL(mapped( int )), SLOT(showHideBrowser( int )) );
+
+ 
+
+
+   
+    //m_tabBar->appendButton( Amarok::icon( "configure" ), 1, 0, QString::null );
+
 }
 
 BrowserBar::~BrowserBar()
 {
-    KConfig* const config = amaroK::config( "BrowserBar" );
+    KConfig* const config = Amarok::config( "BrowserBar" );
     config->writeEntry( "CurrentPane", m_currentIndex != -1 ? QString(currentBrowser()->name()) : QString::null );
     config->writeEntry( "Width", m_browserBox->width() );
 }
@@ -109,8 +132,8 @@ BrowserBar::makeDropProxy( const QString &name, DropProxyTarget *finalTarget )
 int
 BrowserBar::restoreWidth()
 {
-    const int index = indexForName( amaroK::config( "BrowserBar" )->readEntry( "CurrentPane" ) );
-    const int width = amaroK::config( "BrowserBar" )->readNumEntry( "Width", browser( index )->sizeHint().width() );
+    const int index = indexForName( Amarok::config( "BrowserBar" )->readEntry( "CurrentPane" ) );
+    const int width = Amarok::config( "BrowserBar" )->readNumEntry( "Width", browser( index )->sizeHint().width() );
 
     m_browserBox->resize( width, height() );
     m_pos = m_browserBox->width() + m_tabBar->width();
@@ -218,7 +241,7 @@ BrowserBar::event( QEvent *e )
 }
 
 void
-BrowserBar::addBrowser( QWidget *widget, const QString &title, const QString& icon )
+BrowserBar::addBrowser( const QString &identifier, QWidget *widget, const QString &title, const QString& icon )
 {
     const int id = m_tabBar->tabs()->count(); // the next available id
     const QString name( widget->name() );
@@ -228,7 +251,7 @@ BrowserBar::addBrowser( QWidget *widget, const QString &title, const QString& ic
     widget->reparent( m_browserBox, QPoint() );
     widget->hide();
 
-    m_tabBar->appendTab( SmallIcon( icon ), id, title );
+    m_tabBar->appendTab( SmallIcon( icon ), id, title, identifier );
     tab = m_tabBar->tab( id );
     tab->setFocusPolicy( QWidget::NoFocus ); //FIXME you can focus on the tab, but they respond to no input!
 
@@ -245,7 +268,7 @@ BrowserBar::removeMediaBrowser( QWidget *widget )
 {
     BrowserList::iterator it = qFind( m_browsers.begin(), m_browsers.end(), widget );
     if( it != m_browsers.end() )
-        m_browsers.erase( it ); 
+        m_browsers.erase( it );
     QWidget *tab;
     tab = m_tabBar->tab( m_browserIds["MediaBrowser"] );
     m_mapper->removeMappings( tab );
@@ -351,4 +374,35 @@ BrowserBar::indexForName( const QString &name ) const
     return -1;
 }
 
+void
+BrowserBar::showBrowserSelectionMenu()
+{
+      m_tabBar->showTabSelectionMenu(mapToGlobal(QPoint(m_tabManagementButton->pos().x(), m_tabManagementButton->pos().y() +m_tabManagementButton->height() )));
+}
+
+void
+BrowserBar::engineStateChanged( Engine::State state, Engine::State oldState )
+{
+    if( !AmarokConfig::autoShowContextBrowser() || m_currentIndex == -1 )
+        return;
+
+    switch( state ) {
+    case Engine::Playing:
+
+        if( oldState != Engine::Paused && m_currentIndex != -1 ) {
+            m_lastIndex = m_currentIndex;
+            showBrowser( "ContextBrowser" );
+        }
+        break;
+
+    case Engine::Empty:
+
+        if( m_lastIndex >= 0 )
+            showBrowser( m_lastIndex );
+
+    default:
+        ;
+    }
+}
+
 #include "browserbar.moc"
