@@ -14,7 +14,7 @@
 #define AMAROK_COLLECTIONDB_H
 
 #include "engineobserver.h"
-#include "threadweaver.h" //baseclass
+#include "threadmanager.h" //baseclass
 #include "amarok_export.h"
 
 #include <kurl.h>
@@ -38,6 +38,7 @@ class MetaBundle;
 class OrganizeCollectionDialog;
 class PodcastChannelBundle;
 class PodcastEpisodeBundle;
+class QListViewItem;
 class Scrobbler;
 
 class DbConfig
@@ -114,7 +115,7 @@ class DbConnection
         DbConnection();
         virtual ~DbConnection() {}
 
-        virtual QStringList query( const QString& /* statement */ ) = 0;
+        virtual QStringList query( const QString& /* statement */, bool suppressDebug ) = 0;
         virtual int insert( const QString& /* statement */, const QString& /* table */ ) = 0;
         bool isInitialized() const { return m_initialized; }
         virtual bool isConnected() const = 0;
@@ -135,12 +136,13 @@ class SqliteConnection : public DbConnection
         SqliteConnection( const SqliteConfig* /* config */ );
        ~SqliteConnection();
 
-        QStringList query( const QString& /* statement */ );
+        QStringList query( const QString& /* statement */, bool suppressDebug = false );
         int insert( const QString& /* statement */, const QString& /* table */ );
         bool isConnected()const { return true; }
     private:
         static void sqlite_rand( sqlite3_context *context, int /*argc*/, sqlite3_value ** /*argv*/ );
         static void sqlite_power( sqlite3_context *context, int argc, sqlite3_value **argv );
+        static void sqlite_like_new( sqlite3_context *context, int argc, sqlite3_value **argv );
 
         sqlite3* m_db;
 };
@@ -155,7 +157,7 @@ class MySqlConnection : public DbConnection
         MySqlConnection( const MySqlConfig* /* config */ );
        ~MySqlConnection();
 
-        QStringList query( const QString& /* statement */ );
+        QStringList query( const QString& /* statement */, bool suppressDebug = false );
         int insert( const QString& /* statement */, const QString& /* table */ );
         bool isConnected()const { return m_connected; }
         QString lastError() const { return m_error; }
@@ -177,7 +179,7 @@ class PostgresqlConnection : public DbConnection
         PostgresqlConnection( const PostgresqlConfig* /* config */ );
        ~PostgresqlConnection();
 
-        QStringList query( const QString& /* statement */ );
+        QStringList query( const QString& /* statement */, bool suppressDebug = false );
         int insert( const QString& /* statement */, const QString& /* table */ );
         bool isConnected()const { return m_connected; }
         QString lastError() const { return m_error; }
@@ -203,8 +205,9 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         void databaseUpdateDone();
 
-        void scoreChanged( const QString &url, int score );
+        void scoreChanged( const QString &url, float score );
         void ratingChanged( const QString &url, int rating );
+        void labelsChanged( const QString &url );
         void fileMoved( const QString &srcUrl, const QString &dstUrl );
         void fileMoved( const QString &srcUrl, const QString &dstUrl, const QString &uniqueid );
         void fileDeleted( const QString &absPath );
@@ -235,6 +238,8 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
          */
         void initDirOperations();
 
+        enum labelTypes { typeUser = 1 };           //add new types add the end!
+
         QString escapeString(QString string ) const
         {
             return
@@ -248,6 +253,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         QString boolT() const { if (getDbConnectionType() == DbConnection::postgresql) return "true"; else return "1"; }
         QString boolF() const { if (getDbConnectionType() == DbConnection::postgresql) return "false"; else return "0"; }
+        inline bool boolFromSql( const QString &b ) { return ( b == boolT() || b == "t" ); }
         //textColumnType should be used for normal strings, which need to be compared
         //either case-sensitively or -insensitively
         QString textColumnType( int length=255 ) const { if ( getDbConnectionType() == DbConnection::postgresql ) return "TEXT"; else return QString("VARCHAR(%1)").arg(length); }
@@ -266,7 +272,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         int getType() { return getDbConnectionType(); }
 
         //sql helper methods
-        QStringList query( const QString& statement );
+        QStringList query( const QString& statement, bool suppressDebug = false );
         int insert( const QString& statement, const QString& table );
 
         /**
@@ -297,6 +303,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         void setAdminValue( QString noption, QString value );
         void createTables( const bool temporary = false );
         void createIndices(  );
+        void createPermanentIndices();
         void dropTables( const bool temporary = false);
         void clearTables( const bool temporary = false);
         void copyTempTables(  );
@@ -318,6 +325,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         //song methods
         bool addSong( MetaBundle* bundle, const bool incremental = false );
+        void aftCheckPermanentTables( const QString &currdeviceid, const QString &currid, const QString &currurl );
         void doAFTStuff( MetaBundle *bundle, const bool tempTables = true );
         void emitFileAdded( const QString &absPath,
                             const QString &uniqueid = QString::null );
@@ -370,11 +378,11 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         QString getUniqueId( const QString &url );
 
         //statistics methods
-        void addSongPercentage( const QString &url, int percentage,
+        void addSongPercentage( const QString &url, float percentage,
                 const QString &reason, const QDateTime *playtime = 0 );
-        int getSongPercentage( const QString &url );
+        float getSongPercentage( const QString &url );
         int getSongRating( const QString &url );
-        void setSongPercentage( const QString &url, int percentage );
+        void setSongPercentage( const QString &url, float percentage );
         void setSongRating( const QString &url, int percentage, bool toggleHalf = false );
         int getPlayCount( const QString &url );
         QDateTime getFirstPlay( const QString &url );
@@ -388,22 +396,33 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         //album methods
         void checkCompilations( const QString &path, const bool temporary = false );
-        QStringList setCompilation( const QString &album, const bool enabled, const bool updateView = true );
+        void setCompilation( const KURL::List &urls, bool enabled, bool updateView );
         QString albumSongCount( const QString &artist_id, const QString &album_id );
         bool albumIsCompilation( const QString &album_id );
         void sanitizeCompilations();
 
+        //label methods
+        QStringList getLabels( const QString &url, const uint type );
+        void removeLabels( const QString &url, const QStringList &labels, const uint type );
+        bool addLabel( const QString &url, const QString &label, const QString &uid, const uint type );
+        void setLabels( const QString &url, const QStringList &labels, const QString &uid, const uint type );
+
+        void cleanLabels();
+
+        QStringList favoriteLabels( int type = CollectionDB::typeUser, int count = 10 );
+
         //list methods
         QStringList artistList( bool withUnknowns = true, bool withCompilations = true );
         QStringList composerList( bool withUnknowns = true, bool withCompilations = true );
         QStringList albumList( bool withUnknowns = true, bool withCompilations = true );
         QStringList genreList( bool withUnknowns = true, bool withCompilations = true );
         QStringList yearList( bool withUnknowns = true, bool withCompilations = true );
+        QStringList labelList();
 
         QStringList albumListOfArtist( const QString &artist, bool withUnknown = true, bool withCompilations = true );
         QStringList artistAlbumList( bool withUnknown = true, bool withCompilations = true );
 
-        QStringList albumTracks( const QString &artist_id, const QString &album_id, const bool isValue = false );
+        QStringList albumTracks( const QString &artist_id, const QString &album_id );
         QStringList albumDiscTracks( const QString &artist_id, const QString &album_id, const QString &discNumber );
         QStringList artistTracks( const QString &artist_id );
 
@@ -420,7 +439,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         QString findAmazonImage( const QString &artist, const QString &album, const uint width = 1 );
         QString findDirectoryImage( const QString& artist, const QString& album, uint width = 0 );
         QString findEmbeddedImage( const QString& artist, const QString& album, uint width = 1 );
-        QString findMetaBundleImage( MetaBundle trackInformation, const uint = 1 );
+        QString findMetaBundleImage( const MetaBundle &trackInformation, const uint = 1 );
 
         /// ensure the sql only return urls to tracks for efficiency
         static QPixmap createDragPixmapFromSQL( const QString &sql, QString textOverRide=QString::null );
@@ -441,9 +460,11 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
          * @param width the size of the image. 0 == full size, 1 == preview size
          * @param embedded if not NULL, sets a bool indicating whether the path is an embedded image
          */
-        QString albumImage( MetaBundle trackInformation, const bool withShadow = false, uint width = 1, bool* embedded = 0 );
+        QString albumImage( const MetaBundle &trackInformation, const bool withShadow = false, uint width = 1, bool* embedded = 0 );
         QString albumImage( const uint artist_id, const uint album_id, const bool withShadow = false, uint width = 1, bool* embedded = 0 );
         QString albumImage( const QString &artist, const QString &album, const bool withShadow = false, uint width = 1, bool* embedded = 0 );
+        QMap<QListViewItem*, CoverFetcher*> * getItemCoverMap() { return itemCoverMap; }
+        QMutex * getItemCoverMapMutex() { return itemCoverMapMutex; }
 
         bool removeAlbumImage( const uint artist_id, const uint album_id );
         bool removeAlbumImage( const QString &artist, const QString &album );
@@ -460,7 +481,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         void applySettings();
 
-        void setLyrics( const QString& url, const QString& lyrics );
+        void setLyrics( const QString& url, const QString& lyrics, const QString &uniqueid = QString::null );
         QString getLyrics( const QString& url );
 
         /** Remove from the amazon table the item with the specified md5sum **/
@@ -476,6 +497,11 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         void vacuum();
 
+        /**
+        * Cancel the underlying move/copy file action
+        */
+        void cancelMovingFileJob();
+
     protected:
         QCString md5sum( const QString& artist, const QString& album, const QString& file = QString::null );
         void engineTrackEnded( int finalPosition, int trackLength, const QString &reason );
@@ -483,7 +509,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         void timerEvent( QTimerEvent* e );
 
     public slots:
-        void fetchCover( QWidget* parent, const QString& artist, const QString& album, bool noedit );
+        void fetchCover( QWidget* parent, const QString& artist, const QString& album, bool noedit, QListViewItem* item = 0 );
         void scanMonitor();
         void startScan();
         void stopScan();
@@ -498,8 +524,8 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         void similarArtistsFetched( const QString& artist, const QStringList& suggestions );
         void fileOperationResult( KIO::Job *job ); // moveFile depends on it
         void podcastImageResult( KIO::Job *job ); //for fetching remote podcast images
-        void aftMigrateStatisticsUrl( const QString& oldUrl, const QString& newUrl, const QString& uniqueid ); //AFT-enable stats
-        void aftMigrateStatisticsUniqueId( const QString& url, const QString& oldid, const QString& newid );
+        void aftMigratePermanentTablesUrl( const QString& oldUrl, const QString& newUrl, const QString& uniqueid ); //AFT-enable stats
+        void aftMigratePermanentTablesUniqueId( const QString& url, const QString& oldid, const QString& newid );
 
     private:
         //bump DATABASE_VERSION whenever changes to the table structure are made.
@@ -507,7 +533,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         static const int DATABASE_VERSION = 35;
         // Persistent Tables hold data that is somehow valuable to the user, and can't be erased when rescaning.
         // When bumping this, write code to convert the data!
-        static const int DATABASE_PERSISTENT_TABLES_VERSION = 15;
+        static const int DATABASE_PERSISTENT_TABLES_VERSION = 19;
         // Bumping this erases stats table. If you ever need to, write code to convert the data!
         static const int DATABASE_STATS_VERSION = 12;
         // When bumping this, you should provide code to convert the data.
@@ -517,7 +543,6 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         static const int DATABASE_DEVICES_VERSION = 1;
 
         static const int MONITOR_INTERVAL = 60; //sec
-        static const bool DEBUG = false;
 
         static QDir largeCoverDir();
         static QDir tagCoverDir();
@@ -540,7 +565,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
 
         // helpers for embedded images
         QString loadHashFile( const QCString& hash, uint width );
-        bool extractEmbeddedImage( MetaBundle &trackInformation, QCString& hash );
+        bool extractEmbeddedImage( const MetaBundle &trackInformation, QCString& hash );
 
         //general management methods
         void createStatsTable();
@@ -593,10 +618,12 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         bool m_monitor;
         bool m_autoScoring;
 
-        static QMutex *connectionMutex;
-        QImage m_noCover;
+        static QMap<QListViewItem*, CoverFetcher*> *itemCoverMap;
+        static QMutex *itemCoverMapMutex;
+        QImage m_noCover, m_shadowImage;
 
         static QMap<QThread *, DbConnection *> *threadConnections;
+        static QMutex *connectionMutex;
         DbConnection::DbConnectionType m_dbConnType;
         DbConfig *m_dbConfig;
 
@@ -606,6 +633,11 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         bool m_scanInProgress;
         bool m_rescanRequired;
 
+        QStringList m_aftEnabledPersistentTables;
+
+        // Cancel move/copy job
+        bool m_moveFileJobCancelled;
+
         // for handling podcast image url redirects
         QMap<KIO::Job *, QString> m_podcastImageJobs;
 
@@ -613,7 +645,7 @@ class LIBAMAROK_EXPORT CollectionDB : public QObject, public EngineObserver
         QMutex m_mutex;
 };
 
-class INotify : public ThreadWeaver::DependentJob
+class INotify : public ThreadManager::DependentJob
 {
     Q_OBJECT
 
@@ -643,7 +675,7 @@ class QueryBuilder
         enum qBuilderTables  { tabAlbum = 1, tabArtist = 2, tabComposer = 4, tabGenre = 8, tabYear = 16, tabSong = 64,
                                tabStats = 128, tabLyrics = 256, tabPodcastChannels = 512,
                                tabPodcastEpisodes = 1024, tabPodcastFolders = 2048,
-                               tabDevices = 4096
+                               tabDevices = 4096, tabLabels = 8192
                                /* dummy table for filtering */, tabDummy = 0 };
         enum qBuilderOptions { optNoCompilations = 1, optOnlyCompilations = 2, optRemoveDuplicates = 4,
                                optRandomize = 8,
@@ -663,7 +695,7 @@ class QueryBuilder
         static const Q_INT64 valPlayCounter   = 1LL << 10;
         static const Q_INT64 valCreateDate    = 1LL << 11;
         static const Q_INT64 valAccessDate    = 1LL << 12;
-        static const Q_INT64 valPercentage    = 1LL << 13;
+        //static const Q_INT64 valPercentage    = 1LL << 13; // same as valScore
         static const Q_INT64 valArtistID      = 1LL << 14;
         static const Q_INT64 valAlbumID       = 1LL << 15;
         static const Q_INT64 valYearID        = 1LL << 16;
@@ -692,8 +724,15 @@ class QueryBuilder
         static const Q_INT64 valRelativePath  = 1LL << 37;
         static const Q_INT64 valDeviceLabel   = 1LL << 38;
         static const Q_INT64 valMountPoint    = 1LL << 39;
+        //label relevant
+        static const Q_INT64 valType         = 1LL << 40;
 
         static Q_INT64 valForFavoriteSorting();
+        void sortByFavorite();
+
+        // sortByFavoriteAvg() add the average rating, if enabled, the average score, if enabled,
+        // and the average playcounter as return values!
+        void sortByFavoriteAvg();
 
         enum qBuilderFunctions  { funcNone = 0, funcCount = 1, funcMax = 2, funcMin = 4, funcAvg = 8, funcSum = 16 };
 
@@ -755,15 +794,17 @@ class QueryBuilder
         static QString dragSQLFields();
         void initSQLDrag();
 
-        void buildQuery();
+        void buildQuery( bool withDeviceidPlaceholder = false );
         QString getQuery();
-        QString query() { buildQuery(); return m_query; };
+        //use withDeviceidPlaceholder = false if the query isn't run immediately (*CurrentTimeT*)
+        //and replace (*MountedDeviceSelection*) with CollectionDB::instance()->deviceIdSelection()
+        QString query( bool withDeviceidPlaceholder = false ) { buildQuery( withDeviceidPlaceholder ); return m_query; };
         void clear();
 
         QStringList run();
 
         // Transform a string table.value "field" into enum values
-        // @return true if we succeded
+        // @return true if we succeeded
         bool getField(const QString &tableValue, int *table, Q_INT64 *value);
 
     private:
