@@ -25,7 +25,7 @@ class QComboBox;
 class QGroupBox;
 class QVBox;
 
-namespace amaroK {
+namespace Amarok {
     class PluginConfig;
 }
 
@@ -42,7 +42,9 @@ class AmarokConfigDialog : public KConfigDialog
         void addPage( QWidget *page, const QString &itemName, const QString &pixmapName,
                       const QString &header=QString::null, bool manage=true);
 
-        void showPage( const QCString& page );
+        void showPageByName( const QCString& page );
+
+        static int s_currentPage;
 
     protected slots:
         void updateButtons();
@@ -62,7 +64,7 @@ class AmarokConfigDialog : public KConfigDialog
         QString externalBrowser() const;
 
         QComboBox* m_soundSystem;
-        amaroK::PluginConfig *m_engineConfig;
+        Amarok::PluginConfig *m_engineConfig;
         QGroupBox            *m_engineConfigFrame;
         class Options1       *m_opt1;
         class Options2       *m_opt2;
