@@ -6,6 +6,7 @@
 //
 //
 // Author: Jeff Mitchell <kde-dev@emailgoeshere.com>, (C) 2006
+//         Maximilian Kossick <maximilian.kossick@googlemail.com>, (C) 2006
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -23,9 +24,11 @@
 
 #include <dcopclient.h>
 #include <dcopobject.h>
+#include <dcopref.h>
 #include <kapplication.h>
 
 typedef Medium::List MediumList;
+typedef QMap<QString, Medium*>::Iterator MediumIterator;
 
 DeviceManager* DeviceManager::instance()
 {
@@ -55,7 +58,6 @@ DeviceManager::DeviceManager()
         else
         {
             m_valid = true;
-            
             //run the DCOP query here because apparently if you don't run KDE as a DM the first call will fail
             //...go figure
             QByteArray data, replyData;
@@ -63,31 +65,24 @@ DeviceManager::DeviceManager()
             QDataStream arg(data, IO_WriteOnly);
             QStringList result;
             arg << 5;
-            if (!m_dc->call("kded", "mediamanager", "fullList()", data, replyType, replyData))
+            if (!m_dc->call("kded", "mediamanager", "fullList()", data, replyType, replyData, false, 5000))
             {
                 debug() << "During DeviceManager init, error during DCOP call" << endl;
             }
-                                
-            getDevice( "init" );
-            QTimer::singleShot(4000, this, SLOT( reinitDevices() ) ); 
-            debug() << "DeviceManager:  connectDCOPSignal returned sucessfully!" << endl;
+            reconcileMediumMap();
+            debug() << "DeviceManager:  connectDCOPSignal returned successfully!" << endl;
         }
     }
 }
 
 DeviceManager::~DeviceManager()
 {
+    for( MediumIterator it = m_mediumMap.begin(); it != m_mediumMap.end(); it++ )
+        delete (*it);
 }
 
-void DeviceManager::reinitDevices() //SLOT
-{
-    MediumPluginManager *mpm = new MediumPluginManager( 0, true );
-    mpm->detectDevices( true, true );
-    mpm->finished();
-    delete mpm;
-}
-
-void DeviceManager::mediumAdded( QString name )
+void
+DeviceManager::mediumAdded( const QString name )
 {
     DEBUG_BLOCK
     if ( !m_valid )
@@ -101,7 +96,8 @@ void DeviceManager::mediumAdded( QString name )
 }
 
 
-void DeviceManager::mediumRemoved( QString name )
+void
+DeviceManager::mediumRemoved( const QString name )
 {
     DEBUG_BLOCK
     if ( !m_valid )
@@ -119,12 +115,15 @@ void DeviceManager::mediumRemoved( QString name )
     //There is no point in calling getDevice, since it will not be in the list anyways
     emit mediumRemoved( removedMedium, name );
     if ( m_mediumMap.contains(name) )
+    {
+        delete removedMedium;   //If we are to remove it from the map, delete it first
         m_mediumMap.remove(name);
-    delete removedMedium;
+    }
 }
 
 
-void DeviceManager::mediumChanged( QString name )
+void
+DeviceManager::mediumChanged( const QString name )
 {
     DEBUG_BLOCK
     if ( !m_valid )
@@ -150,13 +149,14 @@ Use the Medium's name or id, not the pointer value, for equality comparison!!!
 This function does rebuild the map every time it is called, however this should be rare enough
 that it is not a problem.
 */
-Medium::List DeviceManager::getDeviceList( bool autoonly )
+Medium::List
+DeviceManager::getDeviceList()
 {
-    return Medium::createList( getDeviceStringList( autoonly ) );
+    return Medium::createList( getDeviceStringList() );
 }
 
 QStringList
-DeviceManager::getDeviceStringList( bool autoonly )
+DeviceManager::getDeviceStringList()
 {
     DEBUG_BLOCK
     MediumList currMediumList;
@@ -196,91 +196,89 @@ DeviceManager::getDeviceStringList( bool autoonly )
                 autodetect_insert = Medium::PROPERTIES_COUNT - 1;
         }
     }
-    
-    if( autoonly )
-        return result;
-
-    KConfig *config = amaroK::config( "MediaBrowser" );
-    QMap<QString,QString> savedDevices = config->entryMap( "MediaBrowser" );
-    QMap<QString,QString>::Iterator qit;
-    QString curr, currMountPoint, currName;
-    for( qit = savedDevices.begin(); qit != savedDevices.end(); ++qit )
-    {
-        //only handle manual devices, autodetected devices should be added on the fly
-        if( qit.key().startsWith( "manual|" ) )
-        {
-            curr = qit.key();
-            curr = curr.remove( "manual|" );
-            currName = curr.left( curr.find( '|' ) );
-            currMountPoint = curr.remove( currName + '|' );
-            result.append( "false" );           //autodetected
-            result.append( qit.key() );          //id
-            result.append( currName );          //name
-            result.append( currName );          //label
-            result.append( QString::null );     //userLabel
-            result.append( "unknown" );         //mountable?
-            result.append( QString::null );     //device node
-            result.append( currMountPoint );    //mountPoint
-            result.append( "manual" );          //fsType
-            result.append( "unknown" );         //mounted
-            result.append( QString::null );     //baseURL
-            result.append( QString::null );     //MIMEtype
-            result.append( QString::null );     //iconName
-            result.append( "---" );             //separator
-        }
-    }
 
     return result;
 }
 
-Medium* DeviceManager::getDevice( QString name )
+Medium*
+DeviceManager::getDevice( const QString name )
 {
     DEBUG_BLOCK
     if ( !m_valid )
-        return NULL;
+        return 0;
     debug() << "DeviceManager: getDevice called with name argument = " << name << endl;
     Medium* returnedMedium = 0;
-    Medium* tempMedium = 0;
     MediumList currMediumList = getDeviceList();
 
-    Medium::List::iterator it;
-    QString mountwhere, halid;
-    for ( it = currMediumList.begin(); it != currMediumList.end(); it++ )
+    for ( Medium::List::iterator it = currMediumList.begin(); it != currMediumList.end(); ++it )
     {
-        if ( (*it).fsType() != "vfat" &&
-             (*it).fsType() != "hfsplus" &&
-             (*it).fsType() != "manual" ) //&& other supported fsTypes here later
-            continue;
         if ( (*it).name() == name )
         {
-            returnedMedium = new Medium(*it);
+            MediumIterator secIt;
+            if ( (secIt = m_mediumMap.find( name )) != m_mediumMap.end() )
+            {
+                //Refresh the Medium by reconstructing then copying it over.
+                returnedMedium = *secIt;
+                *returnedMedium = Medium( *it );
+            }
+            else
+            {
+                //No previous version of this Medium - create it
+                returnedMedium = new Medium( *it );
+                m_mediumMap[ name ] = returnedMedium;
+            }
+            break;
         }
-        if( m_mediumMap.contains( name ) )
-        {
-            tempMedium = m_mediumMap[(*it).name()];
-            m_mediumMap.remove( (*it).name() );
-            delete tempMedium;
-        }
-        m_mediumMap[(*it).name()] = new Medium(*it);
     }
-
     return returnedMedium;
 }
 
 void
-DeviceManager::addManualDevice( Medium* added )
+DeviceManager::reconcileMediumMap()
 {
-    m_mediumMap[added->name()] = added;
-    added->setFsType( "manual" );
-    emit mediumAdded( added, added->name() );
+    DEBUG_BLOCK
+    if ( !m_valid )
+        return;
+
+    MediumList currMediumList = getDeviceList();
+
+    Medium::List::iterator it;
+    for ( it = currMediumList.begin(); it != currMediumList.end(); ++it )
+    {
+        MediumIterator locIt;
+        if ( (locIt = m_mediumMap.find( (*it).name() )) != m_mediumMap.end() )
+        {
+            Medium* mediumHolder = (*locIt);
+            *mediumHolder = Medium( *it );
+        }
+        else
+            m_mediumMap[ (*it).name() ] = new Medium(*it);
+    }
+
+    //Sanity check
+    if ( currMediumList.size() != m_mediumMap.size() )
+        warning() << "Number of devices does not equal expected number" << endl;
 }
 
-void
-DeviceManager::removeManualDevice( Medium* removed )
+QString DeviceManager::convertMediaUrlToDevice( QString url )
 {
-    emit mediumRemoved( removed, removed->name() );
-    if( m_mediumMap.contains( removed->name() ) )
-        m_mediumMap.remove( removed->name() );
+    QString device;
+    if ( url.startsWith( "media:" ) || url.startsWith( "system:" ) )
+    {
+        KURL devicePath( url );
+        DCOPRef mediamanager( "kded", "mediamanager" );
+        DCOPReply reply = mediamanager.call( "properties(QString)", devicePath.fileName() );
+        if ( reply.isValid() ) {
+            QStringList properties = reply;
+            device = properties[ 5 ];
+            //kdDebug() << "DeviceManager::convertMediaUrlToDevice() munged to: " << device << "\n";
+        } else
+            device = QString();
+    }
+    else
+        device = url;
+
+    return device;
 }
 
 #include "devicemanager.moc"
