@@ -35,6 +35,7 @@
 #include "helix-errors.h"
 #include "helix-sp.h"
 #include "hxplayercontrol.h"
+#include "amarokconfig.h"
 
 AMAROK_EXPORT_PLUGIN( HelixEngine )
 
@@ -76,6 +77,7 @@ HelixEngine::HelixEngine()
    addPluginProperty( "HasConfigure", "true" );
    addPluginProperty( "HasEqualizer", "true" );
    addPluginProperty( "HasCrossfade", "true" );
+   addPluginProperty( "HasCDDA", "false");
 
    memset(&m_md, 0, sizeof(m_md));
    memset(hscope, 0, 2*sizeof(HelixScope));
@@ -154,7 +156,7 @@ void HelixEngine::onBuffering(int pcnt)
 }
 
 
-amaroK::PluginConfig*
+Amarok::PluginConfig*
 HelixEngine::configure() const
 {
    debug() << "Starting HelixConfigDialog\n";
@@ -242,7 +244,7 @@ HelixEngine::init()
 
    if (!exists || PlayerControl::getError())
    {
-      KMessageBox::error( 0, i18n("The Helix Engine requires the RealPlayer(tm) or HelixPlayer libraries to be installed. Please make sure one is installed, and adjust the paths in \"amaroK Settings\" -> \"Engine\"") );
+      KMessageBox::error( 0, i18n("The Helix Engine requires the RealPlayer(tm) or HelixPlayer libraries to be installed. Please make sure one is installed, and adjust the paths in \"Amarok Settings\" -> \"Engine\"") );
       // we need to return true here so that the user has an oppportunity to change the directory
       //return false;
       return true;
@@ -292,8 +294,13 @@ HelixEngine::load( const KURL &url, bool isStream )
    }
 
    debug() << "xfadeLength is " << m_xfadeLength << endl;
-   if( m_xfadeLength > 0 && m_state == Engine::Playing )
+   if( m_xfadeLength > 0 && m_state == Engine::Playing && !isStream && 
+        ( m_xfadeNextTrack || //set by engine controller when switching tracks automatically
+         (uint) AmarokConfig::crossfadeType() == 0 ||  //crossfade always
+         (uint) AmarokConfig::crossfadeType() == 2 ) ) //crossfade when switching tracks manually)
    {
+      //set m_xfadeNextTrack true here regardless to play() will work correctly; disable in there
+      m_xfadeNextTrack = true;
       int nextPlayer = m_current ? 0 : 1;
 
       // prepare the next player
@@ -355,8 +362,11 @@ HelixEngine::play( uint offset )
 
    nextPlayer = m_current ? 0 : 1;
 
-   if (m_xfadeLength && !offset && isPlaying(m_current))
+   if (m_xfadeLength && m_xfadeNextTrack && !offset && isPlaying(m_current))
+   {
+      m_xfadeNextTrack = false;
       PlayerControl::start(nextPlayer, true, m_xfadeLength);
+   }
    else
       PlayerControl::start(nextPlayer);
 
@@ -405,11 +415,27 @@ HelixEngine::stop()
    if (!m_inited)
       return;
 
-   debug() << "In stop\n";
-   cleanup();
-   cleanUpStream(m_current);
-   m_state = Engine::Empty;
-   emit stateChanged( m_state );
+   debug() << "In stop where=" << where(m_current) << " duration=" << duration(m_current) << endl;
+
+   if( AmarokConfig::fadeout() && !m_pfade[m_current].m_fadeactive && state() == Engine::Playing ) 
+   {
+      debug() << "fading out...\n";
+      m_state = Engine::Empty;
+      emit stateChanged( Engine::Empty ); // tell the controller not to bother you anymore
+
+      m_pfade[m_current].m_fadeactive = true;
+      m_pfade[m_current].m_stopfade = true;
+      m_pfade[m_current].m_startfadetime = PlayerControl::where(m_current);
+      setFadeout(true, AmarokConfig::fadeoutLength(), m_current);
+   }
+   else
+   {
+      debug() << "Stopping immediately\n";
+      cleanup();
+      cleanUpStream(m_current);
+      m_state = Engine::Empty;
+      emit stateChanged( m_state );
+   }
 }
 
 
@@ -420,9 +446,10 @@ void HelixEngine::play_finished(int playerIndex)
    resetScope(playerIndex);
    memset(&hscope[playerIndex], 0, sizeof(HelixScope));
    memset(&m_pfade[playerIndex], 0, sizeof(FadeTrack));
-   if (playerIndex == m_current)
+   if (playerIndex == m_current && !m_pfade[playerIndex].m_stopfade && !m_pfade[playerIndex].m_fadeactive)
    {
       m_state = Engine::Idle;
+      emit stateChanged( m_state );
       emit trackEnded();
    }
 }
@@ -441,7 +468,17 @@ HelixEngine::pause()
       m_state = Engine::Paused;
       emit stateChanged( Engine::Paused );
    }
-   else if ( m_state == Engine::Paused )
+}
+
+void
+HelixEngine::unpause()
+{
+   if (!m_inited)
+      return;
+
+   // TODO: PAUSE in XFADE
+   debug() << "In unpause\n";
+   if ( m_state == Engine::Paused )
    {
       PlayerControl::resume(m_current);
       m_state = Engine::Playing;
@@ -536,13 +573,23 @@ HelixEngine::timerEvent( QTimerEvent * )
    PlayerControl::dispatch(); // dispatch the players
    if ( m_xfadeLength <= 0 && m_state == Engine::Playing && PlayerControl::done(m_current) )
       play_finished(m_current);
-   else if ( m_xfadeLength > 0 )
+   else if ( m_xfadeLength > 0 || AmarokConfig::fadeout() )
    {
       if ( m_state == Engine::Playing && isPlaying(m_current?0:1) && PlayerControl::done(m_current?0:1) )
          hscope[m_current?0:1].m_lasttime = 0;
 
-      if (m_pfade[m_current?0:1].m_fadeactive && 
-          PlayerControl::where(m_current?0:1) > m_pfade[m_current?0:1].m_startfadetime + (unsigned)m_xfadeLength)
+      // fade on stop finished
+      if ( m_pfade[m_current].m_stopfade && m_pfade[m_current].m_fadeactive &&
+          (PlayerControl::where(m_current) > m_pfade[m_current].m_startfadetime + (unsigned)AmarokConfig::fadeoutLength() ||
+           PlayerControl::done(m_current)) )
+      {
+         debug() << "Stop fade end\n";
+         stop();
+      }
+
+      // crossfade finished
+      if ( m_pfade[m_current?0:1].m_fadeactive &&
+           PlayerControl::where(m_current?0:1) > m_pfade[m_current?0:1].m_startfadetime + (unsigned)m_xfadeLength)
          play_finished(m_current?0:1);
    }
 
@@ -580,7 +627,7 @@ HelixEngine::timerEvent( QTimerEvent * )
       {
          bndl.album = bndl.album.remove(0, 9);
          QStringList sl = QStringList::split('|', bndl.album);
-         for ( QStringList::Iterator it = sl.begin(); it != sl.end(); ++it ) 
+         for ( QStringList::Iterator it = sl.begin(); it != sl.end(); ++it )
          {
             if ((*it).startsWith("title="))
                 bndl.title = (*it).section('=', 1, 1);
@@ -755,7 +802,7 @@ int HelixEngine::scope(int playerIndex)
                hscope[playerIndex].m_currentScope[hscope[playerIndex].m_scopeindex] = *pint;
                hscope[playerIndex].m_scopeindex++;
                hscope[playerIndex].m_currentScope[hscope[playerIndex].m_scopeindex] = *pint;
-               hscope[playerIndex].m_scopeindex++;               
+               hscope[playerIndex].m_scopeindex++;
             }
             else
             {
