@@ -8,8 +8,9 @@
 
 
 Engine::Base::Base()
-        : amaroK::Plugin()
+        : Amarok::Plugin()
         , m_xfadeLength( 0 )
+        , m_xfadeNextTrack( false )
         , m_volume( 50 )
         , m_scope( SCOPESIZE )
         , m_isStream( false )
