@@ -277,7 +277,7 @@ bool EngineController::installDistroCodec( const QString& engine /*Filetype type
         QString installScript = service->exec();
         if( !installScript.isNull() ) //just a sanity check
         {
-            KGuiItem installButton("Install MP3 Support");
+            KGuiItem installButton( i18n( "Install MP3 Support" ) );
             if(KMessageBox::questionYesNo(PlaylistWindow::self()
             , i18n("Amarok currently cannot play MP3 files.")
             , i18n( "No MP3 Support" )
