@@ -72,14 +72,13 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
     SearchPane *searchPane;
 
     KURL *location;
-    KFileItem *currentFolder;
 
     // Try to keep filebrowser working even if not in a medium context
     // so if a medium object not passed in, keep earlier behavior
     if (!medium) {
         m_medium = 0;
         location = new KURL( Amarok::config( "Filebrowser" )->readPathEntry( "Location", QDir::homeDirPath() ) );
-        currentFolder = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, *location );
+        KFileItem *currentFolder = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, *location );
         //KIO sucks, NetAccess::exists puts up a dialog and has annoying error message boxes
         //if there is a problem so there is no point in using it anyways.
         //so... setting the diroperator to ~ is the least sucky option
@@ -91,7 +90,6 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
     else{
         m_medium = medium;
         location = new KURL( m_medium->mountPoint() );
-        currentFolder = new KFileItem( KFileItem::Unknown, KFileItem::Unknown, *location );
     }
 
     KActionCollection* ac = new KActionCollection( this );
@@ -108,8 +106,8 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
 
         connect( button, SIGNAL(clicked()), m_filter, SLOT(clear()) );
 
-        QToolTip::add( button, i18n( "Clear filter" ) );
-        QToolTip::add( m_filter, i18n( "Enter space-separated terms to filter the directory-listing" ) );
+        QToolTip::add( button, i18n( "Clear search field" ) );
+        QToolTip::add( m_filter, i18n( "Enter space-separated terms to search in the directory-listing" ) );
     }
 
     { //Directory Listing
@@ -171,6 +169,9 @@ FileBrowser::FileBrowser( const char * name, Medium * medium )
         menu->clear();
         menu->insertItem( SmallIconSet( Amarok::icon( "files" ) ), i18n( "&Load" ), MakePlaylist );
         menu->insertItem( SmallIconSet( Amarok::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), AppendToPlaylist );
+        menu->insertItem( SmallIconSet( Amarok::icon( "queue_track" ) ), i18n( "&Queue Track" ), QueueTrack );
+        menu->insertItem( SmallIconSet( Amarok::icon( "queue_track" ) ), i18n( "&Queue Tracks" ), QueueTracks );
+
         menu->insertItem( SmallIconSet( Amarok::icon( "save" ) ), i18n( "&Save as Playlist..." ), SavePlaylist );
         menu->insertSeparator();
 
@@ -416,7 +417,7 @@ FileBrowser::slotViewChanged( KFileView *view )
 inline void
 FileBrowser::activate( const KFileItem *item )
 {
-    Playlist::instance()->insertMedia( item->url(), Playlist::Unique | Playlist::Append  );
+    Playlist::instance()->insertMedia( item->url(), Playlist::DefaultOptions );
 }
 
 inline void
@@ -425,6 +426,10 @@ FileBrowser::prepareContextMenu()
     const KFileItemList &items = *m_dir->selectedItems();
     static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( SavePlaylist,
         items.count() > 1 || ( items.count() == 1 && items.getFirst()->isDir() ) );
+    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTrack,
+        items.count() == 1  );
+    static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( QueueTracks,
+        items.count() > 1 );
     static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MediaDevice,
         MediaBrowser::isAvailable() );
     static_cast<KActionMenu*>(m_dir->actionCollection()->action("popupMenu"))->popupMenu()->setItemVisible( MoveToCollection, !CollectionDB::instance()->isDirInCollection( url().path() ) );
@@ -449,6 +454,11 @@ FileBrowser::contextMenuActivated( int id )
         Playlist::instance()->insertMedia( selectedItems() );
         break;
 
+    case QueueTrack:
+    case QueueTracks:
+        Playlist::instance()->insertMedia( selectedItems(), Playlist::Queue );
+        break;
+
     case EditTags:
         {
             KURL::List list = Amarok::recursiveUrlExpand( selectedItems() );
