@@ -22,7 +22,7 @@
 
 #include <khtml_part.h>
 #include <konqsidebarplugin.h>
-#include <dcopclient.h> 
+#include <dcopclient.h>
 #include <qslider.h>
 #include <qvbox.h>
 #include <khtmlview.h>
@@ -78,7 +78,8 @@ private:
    QSlider* vol_slider;
    AmarokPlayerInterface_stub *playerStub;
    AmarokPlaylistInterface_stub *playlistStub;
-   
+   AmarokContextBrowserInterface_stub *contextStub;
+
 public slots:
     void updateBrowser(const QString&);
     void updateStatus();
@@ -91,10 +92,11 @@ public slots:
     void volChanged(int vol);
     void openURLRequest( const KURL & );
     void checkForAmarok();
-    void cbHome() { openURLRequest( KURL("show:home") ) ; }
-    void lyrics() { openURLRequest( KURL("show:lyrics") ) ; }
-    void currentTrack() { openURLRequest( KURL("show:context") ) ; }
-    void wiki() { openURLRequest( KURL("show:wiki") ) ; }
+    void noAmarokRunning();
+    void runAmarok();
+    void lyrics() { contextStub->showLyrics(); }
+    void currentTrack() { contextStub->showCurrentTrack(); }
+    void wiki() { contextStub->showWiki(); }
 };
 
 #endif
