@@ -1,3 +1,24 @@
+/***************************************************************************
+    copyright            : (C) 2002, 2003, 2006 by Jochen Issing
+    email                : jochen.issing@isign-softart.de
+ ***************************************************************************/
+
+/***************************************************************************
+ *   This library is free software; you can redistribute it and/or modify  *
+ *   it  under the terms of the GNU Lesser General Public License version  *
+ *   2.1 as published by the Free Software Foundation.                     *
+ *                                                                         *
+ *   This library is distributed in the hope that it will be useful, but   *
+ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
+ *   Lesser General Public License for more details.                       *
+ *                                                                         *
+ *   You should have received a copy of the GNU Lesser General Public      *
+ *   License along with this library; if not, write to the Free Software   *
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,            *
+ *   MA  02110-1301  USA                                                   *
+ ***************************************************************************/
+
 #include <tbytevector.h>
 #include <tstring.h>
 #include "tlist.h"
@@ -27,7 +48,7 @@ public:
   MP4::Tag                    mp4tag;
   //! container for the audio properties returned by properties() function
   MP4::AudioProperties        mp4audioproperties;
-  //! is set to valid after successfull parsing
+  //! is set to valid after successfully parsing
   bool                        isValid;
 };
 
@@ -138,6 +159,10 @@ bool MP4::File::readSizeAndType( TagLib::uint& size, MP4::Fourcc& fourcc )
          static_cast<unsigned char>(readsize[2]) <<  8 |
          static_cast<unsigned char>(readsize[3]);
 
+  // type and size seem to be part of the stored size
+  if( size < 8 )
+    return false;
+
   // set fourcc
   fourcc = readtype.data();
 
