@@ -156,10 +156,7 @@ bool MP4::File::save()
     }
 #endif
 
-    if(!MP4Close(handle))
-    {
-        fprintf(stderr, "close failed\n");
-    }
+    MP4Close(handle);
 
     mp4file = MP4Read(name());
     if(mp4file == MP4_INVALID_FILE_HANDLE)
