@@ -36,14 +36,17 @@
 #include "m4a/mp4file.h"
 #endif
 
+#ifndef TAGLIB_15
 #include "trueaudio/taglib_trueaudiofiletyperesolver.h"
 #include "trueaudio/ttafile.h"
 #include "wavpack/taglib_wavpackfiletyperesolver.h"
 #include "wavpack/wvfile.h"
 #include "speex/taglib_speexfiletyperesolver.h"
 #include "speex/speexfile.h"
-#include "wma/taglib_wmafiletyperesolver.h"
-#include "wma/wmafile.h"
+#endif
+
+#include "asf/taglib_asffiletyperesolver.h"
+#include "asf/asffile.h"
 #include "rmff/taglib_realmediafiletyperesolver.h"
 #include "rmff/taglib_realmediafile.h"
 #include "audible/taglib_audiblefiletyperesolver.h"
@@ -95,7 +98,7 @@ TagLib::File *MimeTypeFileTypeResolver::createFile(const char *fileName,
             || mimetype->is( "video/x-msvideo" )
             || mimetype->is( "video/x-ms-wmv" ) )
     {
-        return new TagLib::WMA::File(fileName, readProperties, propertiesStyle);
+        return new TagLib::ASF::File(fileName, readProperties, propertiesStyle);
     }
     else if( mimetype->is( "audio/vnd.rn-realaudio" )
             || mimetype->is( "audio/x-pn-realaudio" )
@@ -130,12 +133,14 @@ void registerTaglibPlugins()
 {
     //TagLib::FileRef::addFileTypeResolver(new MimeTypeFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new MP4FileTypeResolver);
-    TagLib::FileRef::addFileTypeResolver(new WMAFileTypeResolver);
+    TagLib::FileRef::addFileTypeResolver(new ASFFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new RealMediaFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new AudibleFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new AACFileTypeResolver);
+    TagLib::FileRef::addFileTypeResolver(new WavFileTypeResolver);
+#ifndef TAGLIB_15    
     TagLib::FileRef::addFileTypeResolver(new WavPackFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new SpeexFileTypeResolver);
     TagLib::FileRef::addFileTypeResolver(new TTAFileTypeResolver);
-    TagLib::FileRef::addFileTypeResolver(new WavFileTypeResolver);
+#endif
 }
