@@ -81,8 +81,9 @@ public:
   { return m_state; }
   
   // Where are we storing the .mood file?
-  QString moodFilename( void );
-  QString moodFilename( bool withMusic );
+  static QString moodFilename( const KURL &url );
+  static QString moodFilename( const KURL &url, bool withMusic );
+  static bool copyFile( const QString &srcPath, const QString &dstPath );
 
   static bool executableExists( void );
   
@@ -111,7 +112,7 @@ private:
 
 class KProcess;
 
-// For internal use only.
+// For internal use only (well, mostly)
 class MoodServer : public QObject
 {
   Q_OBJECT
@@ -133,6 +134,11 @@ private slots:
   void slotNewJob( void );
   void slotMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic );
 
+public slots:
+  // Moodbar file organization slots
+  void slotFileDeleted( const QString &absPath );
+  void slotFileMoved( const QString &srcPath, const QString &dstPath );
+
 private:
 
   class ProcData
@@ -142,7 +148,7 @@ private:
       : m_url( url ), m_infile( infile ), m_outfile( outfile )
       , m_refcount( 1 )
     {}
-    ProcData( void ) {}
+    ProcData( void ) : m_refcount( 0 ) {}
 
     KURL    m_url;
     QString m_infile;
