@@ -46,7 +46,7 @@ email                : markey@web.de
 #include <kwin.h>            //eventFilter()
 
 //simple function for fetching amarok images
-namespace amaroK
+namespace Amarok
 {
     //TODO remove these, they suck, do a generic getImage
 
@@ -65,7 +65,7 @@ namespace amaroK
     }
 }
 
-using amaroK::getPNG;
+using Amarok::getPNG;
 
 
 //fairly pointless template which was designed to make the ctor clearer,
@@ -120,7 +120,7 @@ PlayerWidget::PlayerWidget( QWidget *parent, const char *name, bool enablePlayli
         //NOTE we use a layout for the buttons so resizing will be possible
         m_pFrameButtons = createWidget<QHBox>( QRect(0, 118, 311, 22), this );
 
-        KActionCollection *ac =amaroK::actionCollection();
+        KActionCollection *ac =Amarok::actionCollection();
 
         //FIXME change the names of the icons to reflect kde names so we can fall back to them if necessary
                          new NavButton( m_pFrameButtons, "prev", ac->action( "prev" ) );
@@ -140,11 +140,11 @@ PlayerWidget::PlayerWidget( QWidget *parent, const char *name, bool enablePlayli
     } //</NavButtons>
 
     { //<Sliders>
-        m_pSlider    = new amaroK::PrettySlider( Qt::Horizontal, 
-                                                 amaroK::PrettySlider::Pretty, this );
-        m_pVolSlider = new amaroK::PrettySlider( Qt::Vertical, 
-                                                 amaroK::PrettySlider::Pretty, this, 
-                                                 amaroK::VOLUME_MAX );
+        m_pSlider    = new Amarok::PrettySlider( Qt::Horizontal,
+                                                 Amarok::PrettySlider::Pretty, this );
+        m_pVolSlider = new Amarok::PrettySlider( Qt::Vertical,
+                                                 Amarok::PrettySlider::Pretty, this,
+                                                 Amarok::VOLUME_MAX );
 
         m_pSlider->setGeometry( 4,103, 303, 12 );
         m_pVolSlider->setGeometry( 294,18, 12,79 );
@@ -185,11 +185,11 @@ PlayerWidget::PlayerWidget( QWidget *parent, const char *name, bool enablePlayli
     m_pPlaylistButton->setOn( parent->isShown() || enablePlaylist );
 
 
-    m_pDescription = createWidget<QLabel>( QRect(4,6, 130,10), this );
+    m_pDescription = createWidget<QLabel>( QRect(4,6, 250,10), this );
     m_pTimeSign    = createWidget<QLabel>( QRect(6,40, 10,10), this, 0, Qt::WRepaintNoErase );
     m_pVolSign     = createWidget<QLabel>( QRect(295,7, 9,8),  this );
 
-    m_pDescription->setPixmap( getPNG( "description" ) );
+    m_pDescription->setText( i18n( "Artist-Title|Album|Length" ) );
     m_pVolSign    ->setPixmap( getPNG( "vol_speaker" ) );
 
 
@@ -263,7 +263,7 @@ void PlayerWidget::setScroll( const QStringList &list )
     {
         p.drawText( x, baseline, *it );
         x += fm.width( *it );
-        p.fillRect( x + 8, separatorYPos, 4, 4, amaroK::ColorScheme::Foreground );
+        p.fillRect( x + 8, separatorYPos, 4, 4, Amarok::ColorScheme::Foreground );
         x += separatorWidth;
     }
 
@@ -401,7 +401,7 @@ void PlayerWidget::timeDisplay( int ms )
 {
     int seconds = ms / 1000;
     const int songLength = EngineController::instance()->bundle().length();
-    const bool showRemaining = AmarokConfig::timeDisplayRemaining() && songLength > 0;
+    const bool showRemaining = AmarokConfig::leftTimeDisplayRemaining() && songLength > 0;
 
     if( showRemaining ) seconds = songLength - seconds;
 
@@ -433,7 +433,7 @@ void PlayerWidget::determineAmarokColors() //static
         : KGlobalSettings::highlightColor()
       ).getHsv( &hue, &s, &v );
 
-    using namespace amaroK::ColorScheme;
+    using namespace Amarok::ColorScheme;
 
     Text       = Qt::white;
     Background = comodulate( hue, 0x002090 );
@@ -450,15 +450,15 @@ void PlayerWidget::determineAmarokColors() //static
            hue = h;
     }
 
-    Base = comodulate( hue, amaroK::blue );
+    Base = comodulate( hue, Amarok::blue );
 }
 
 void PlayerWidget::setModifiedPalette()
 {
     QPalette p = QApplication::palette();
     QColorGroup cg = p.active();
-    cg.setColor( QColorGroup::Background, amaroK::ColorScheme::Base );
-    cg.setColor( QColorGroup::Foreground, amaroK::ColorScheme::Text );
+    cg.setColor( QColorGroup::Background, Amarok::ColorScheme::Base );
+    cg.setColor( QColorGroup::Foreground, Amarok::ColorScheme::Text );
     setPalette( QPalette(cg, p.disabled(), cg) );
 }
 
@@ -476,7 +476,7 @@ void PlayerWidget::applySettings()
     //update the scroller
     switch( EngineController::engine()->state() ) {
     case Engine::Empty:
-        m_scrollTextPixmap.fill( amaroK::ColorScheme::Base );
+        m_scrollTextPixmap.fill( Amarok::ColorScheme::Base );
         update();
         break;
     default:
@@ -534,7 +534,7 @@ bool PlayerWidget::event( QEvent *e )
     case QEvent::Drop:
     case QEvent::Close:
 
-        amaroK::genericEventHandler( this, e );
+        Amarok::genericEventHandler( this, e );
         return true; //we handled it
 
     case QEvent::ApplicationPaletteChange:
@@ -753,11 +753,16 @@ void PlayerWidget::paintEvent( QPaintEvent* )
 }
 
 
+void PlayerWidget::contextMenuEvent( QMouseEvent *e )
+{
+    Amarok::Menu::instance()->exec( e->globalPos() );
+}
+
 void PlayerWidget::mousePressEvent( QMouseEvent *e )
 {
     if ( e->button() == QMouseEvent::RightButton )
     {
-        amaroK::Menu::instance()->exec( e->globalPos() );
+        //Amarok::Menu::instance()->exec( e->globalPos() );
     }
     else if ( m_pAnalyzer->geometry().contains( e->pos() ) )
     {
@@ -771,7 +776,7 @@ void PlayerWidget::mousePressEvent( QMouseEvent *e )
 
         if ( rect.contains( e->pos() ) )
         {
-            AmarokConfig::setTimeDisplayRemaining( !AmarokConfig::timeDisplayRemaining() );
+            AmarokConfig::setLeftTimeDisplayRemaining( !AmarokConfig::leftTimeDisplayRemaining() );
             timeDisplay( EngineController::engine()->position() );
         }
         else m_startDragPos = e->pos();
