@@ -36,9 +36,9 @@
 //TODO decide whether to use 16 bit integers or 32 bit floats as data sent to analyzers
 //TODO allow visualizations to determine their own data sizes
 
-/// @class amaroK::SocketServer
+/// @class Amarok::SocketServer
 
-amaroK::SocketServer::SocketServer( const QString &socketName, QObject *parent )
+Amarok::SocketServer::SocketServer( const QString &socketName, QObject *parent )
         : QServerSocket( parent )
 {
     m_sockfd = ::socket( AF_UNIX, SOCK_STREAM, 0 );
@@ -75,7 +75,7 @@ amaroK::SocketServer::SocketServer( const QString &socketName, QObject *parent )
     this->setSocket( m_sockfd );
 }
 
-amaroK::SocketServer::~SocketServer()
+Amarok::SocketServer::~SocketServer()
 {
     if( m_sockfd != -1 )
         ::close( m_sockfd );
@@ -86,7 +86,7 @@ amaroK::SocketServer::~SocketServer()
 /// @class Vis::SocketServer
 
 Vis::SocketServer::SocketServer( QObject *parent )
-        : amaroK::SocketServer( "amarok.visualization_socket", parent )
+        : Amarok::SocketServer( "amarok.visualization_socket", parent )
 {}
 
 void
@@ -157,7 +157,7 @@ Vis::Selector::Selector( QWidget *parent )
         : QListView( parent, "Vis::Selector::instance", Qt::WType_Dialog )
         , m_server( new SocketServer( this ) )
 {
-    amaroK::OverrideCursor waitcursor;
+    Amarok::OverrideCursor waitcursor;
 
     setCaption( kapp->makeStdCaption( i18n( "Visualizations" ) ) );
 
@@ -173,25 +173,16 @@ Vis::Selector::Selector( QWidget *parent )
     reinterpret_cast<QWidget*>(header())->hide();
 
 
-     connect( this, SIGNAL(rightButtonPressed( QListViewItem*, const QPoint&, int )),
+     connect( this, SIGNAL(contextMenuRequested( QListViewItem*, const QPoint&, int )),
               this, SLOT(rightButton( QListViewItem*, const QPoint&, int )) );
 
-    //can I get a pointer to the data section of a QCString?
+    // Can I get a pointer to the data section of a QCString?
     char str[4096];
-    FILE *vis = popen( "amarok_xmmswrapper2 --list", "r" );
+    FILE* vis = popen( "amarok_libvisual --list", "r" );
     str[ fread( static_cast<void*>( str ), sizeof(char), 4096, vis ) ] = '\0';
     pclose( vis );
 
-    QStringList entries = QStringList::split( '\n', QString::fromLocal8Bit( str ) );
-
-    for( QStringList::ConstIterator it = entries.begin(); it != entries.end(); ++it )
-        new Item( this, "amarok_xmmswrapper2", *it, "xmms" );
-
-    vis = popen( "amarok_libvisual --list", "r" );
-    str[ fread( static_cast<void*>( str ), sizeof(char), 4096, vis ) ] = '\0';
-    pclose( vis );
-
-    entries = QStringList::split( '\n', QString::fromLocal8Bit( str ) );
+    const QStringList entries = QStringList::split( '\n', QString::fromLocal8Bit( str ) );
 
     for( QStringList::ConstIterator it = entries.begin(); it != entries.end(); ++it )
         new Item( this, "amarok_libvisual", *it, "libvisual" );
@@ -242,20 +233,13 @@ Vis::Selector::rightButton( QListViewItem* qitem, const QPoint& pos, int )
     Item *item = static_cast<Item*>( qitem );
 
     KPopupMenu menu( this );
-    menu.insertItem( i18n( "Configure" ), 0 );
-    menu.insertItem( i18n( "Fullscreen" ), 1 );
+    menu.insertItem( i18n( "Fullscreen" ), 0 );
 
-    if( item->m_proc && item->m_proc->isRunning() )
-        // xmms has no fullscreen, libvisual no configure
-        menu.setItemEnabled( item->text( 1 ) == "xmms" ? 1 : 0, false );
-    else {
+    if( !item->m_proc || !item->m_proc->isRunning() )
         menu.setItemEnabled( 0, false );
-        menu.setItemEnabled( 1, false );
-    }
 
     switch( menu.exec( pos ) ) {
-        case 0: ::send( item->m_sockfd, "configure", 10, 0 ); break;
-        case 1: ::send( item->m_sockfd, "fullscreen", 11, 0 ); break;
+        case 0: ::send( item->m_sockfd, "fullscreen", 11, 0 ); break;
         default: break;
     }
 }
@@ -269,7 +253,7 @@ Vis::Selector::viewportPaintEvent( QPaintEvent *e )
 
         //TODO the right message if amarok_libvisual is present but libvisual isn't
         hide();
-        amaroK::StatusBar::instance()->longMessage( i18n(
+        Amarok::StatusBar::instance()->longMessage( i18n(
                 "<div align=center>"
                 "<h3>No Visualizations Found</h3>"
                 "Possible reasons:"
@@ -297,7 +281,7 @@ Vis::Selector::Item::stateChange( bool ) //SLOT
 {
     switch( state() ) {
     case On:
-        m_proc = new amaroK::Process();
+        m_proc = new Amarok::Process();
        *m_proc << KStandardDirs::findExe( m_command )
                << Selector::instance()->m_server->path()
                << text( 0 );
