@@ -33,6 +33,7 @@
 #include <qmessagebox.h>
 #include <qpainter.h>
 #include <qtimer.h>
+#include <qtooltip.h>
 
 namespace KDE
 {
@@ -54,6 +55,9 @@ PopupMessage::PopupMessage( QWidget *parent, QWidget *anchor, int timeout, const
     setFrameShape( QFrame::StyledPanel );
     setWFlags( Qt::WX11BypassWM );
 
+    QPalette p = QToolTip::palette();
+    setPalette( p );
+
     QHBoxLayout *hbox;
     QLabel *label;
     KActiveLabel *alabel;
@@ -73,6 +77,7 @@ PopupMessage::PopupMessage( QWidget *parent, QWidget *anchor, int timeout, const
     alabel = new KActiveLabel( this, "label" );
     alabel->setTextFormat( Qt::RichText );
     alabel->setSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Preferred );
+    alabel->setPalette( p );
 
     hbox->add( alabel );
 
@@ -90,13 +95,13 @@ void PopupMessage::addWidget( QWidget *widget )
     adjustSize();
 }
 
-void PopupMessage::showCloseButton( const bool show )
+void PopupMessage::setShowCloseButton( const bool show )
 {
     static_cast<KPushButton*>(child( "closeButton" ))->setShown( show );
     adjustSize();
 }
 
-void PopupMessage::showCounter( const bool show )
+void PopupMessage::setShowCounter( const bool show )
 {
     m_showCounter = show;
     static_cast<QFrame*>(child( "counterVisual" ))->setShown( show );
